==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/WSPROMPTFIELDID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour WSPROMPTFIELDID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="WSPROMPTFIELDID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WSPROMPTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WSPROMPTFIELDID_Type", propOrder = {
    "wspromptid",
    "line"
})
public class WSPROMPTFIELDID_Type {

    @XmlElement(name = "WSPROMPTID", required = true)
    protected WSPROMPTID_Type wspromptid;
    @XmlElement(name = "LINE")
    protected long line;

    /**
     * Obtient la valeur de la propriété wspromptid.
     * 
     * @return
     *     possible object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public WSPROMPTID_Type getWSPROMPTID() {
        return wspromptid;
    }

    /**
     * Définit la valeur de la propriété wspromptid.
     * 
     * @param value
     *     allowed object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public void setWSPROMPTID(WSPROMPTID_Type value) {
        this.wspromptid = value;
    }

    /**
     * Obtient la valeur de la propriété line.
     * 
     */
    public long getLINE() {
        return line;
    }

    /**
     * Définit la valeur de la propriété line.
     * 
     */
    public void setLINE(long value) {
        this.line = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/WSPROMPTFIELDID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for WSPROMPTFIELDID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WSPROMPTFIELDID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WSPROMPTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WSPROMPTFIELDID_Type", propOrder = {
    "wspromptid",
    "line"
})
public class WSPROMPTFIELDID_Type {

    @XmlElement(name = "WSPROMPTID", required = true)
    protected WSPROMPTID_Type wspromptid;
    @XmlElement(name = "LINE")
    protected long line;

    /**
     * Gets the value of the wspromptid property.
     * 
     * @return
     *     possible object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public WSPROMPTID_Type getWSPROMPTID() {
        return wspromptid;
    }

    /**
     * Sets the value of the wspromptid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public void setWSPROMPTID(WSPROMPTID_Type value) {
        this.wspromptid = value;
    }

    /**
     * Gets the value of the line property.
     * 
     */
    public long getLINE() {
        return line;
    }

    /**
     * Sets the value of the line property.
     * 
     */
    public void setLINE(long value) {
        this.line = value;
    }

}
